# Figure 2: bifurcation diagram

using OrdinaryDiffEq
using PyPlot
using Peaks
using ProgressMeter
include("my_functions.jl")
pygui(true)


# parameters
V_E = -17.63;
A = 0.1;
dt = 0.2;
t0 = (0., 2000.);

# initial condition
y0 = [-65.;0.];

M = 3000;
N = 2000;
omega0 = range(0.0005,stop=.5,length=M);
#omega0 = range(0.28,stop=.35,length=M);

# solve model
p = Progress(M);
dx = zeros(N,M);
@inbounds for (i,omega) in enumerate(omega0)
    
    par = (A, omega, V_E)
    
    # solve model
    prob = ODEProblem(ml!,y0,t0,par);
    sol = solve(prob,Tsit5(),saveat=dt, dtmax=1.0);
    x = sol[1,3000:end];
    x2 = copy(x);
    x2[x.<0] .= 0;
    t = sol.t[3000:end];
    

    # find peaks
    idx = Peaks.findmaxima(x2) # find local maxima

    # interspike intervalls
    dx[1:length(idx[1])-1,i] = diff(t[idx[1]])    
    next!(p)
end

# plot bifurcation diagram
PyPlot.clf()
PyPlot.scatter(omega0*ones(200)', dx[1:200,:]', s=.1, marker=".")
