# Figure 5: time series of coupled neurons for different g

using OrdinaryDiffEq
using PyPlot
include("my_functions.jl")

###### calculate time series for coupled neurons
# parameters
dt = 0.05
omega = .286; 
V_E = -17.63;
A = 0.1;

# initial condition
y0 = [-65.6;0. ;-60.; 0.01];

# time
t0 = (0., 2800.);
t = 0.:dt:2800.; 

# solve model
# g = 0.01
prob = ODEProblem(ml2!,y0,t0,(A, omega, V_E, 0.01));
sol1 = solve(prob,Tsit5(),saveat=dt, dtmax=1.0);

# g = 0.08
prob = ODEProblem(ml2!,y0,t0,(A, omega, V_E, 0.08));
sol2 = solve(prob,Tsit5(),saveat=dt, dtmax=1.0);

# time series
y11 = copy(sol1[1,10001:10:50000]); y21 = copy(sol1[3,10001:10:50000]);
y12 = copy(sol2[1,10001:10:50000]); y22 = copy(sol2[3,10001:10:50000]);
t = copy(sol2.t[10001:10:50000])

# plot time series
fig = PyPlot.figure(figsize=(10,3))
ax1 = fig.add_subplot(1,2,1)
ax1.plot(t[50:850],y11[50:850])
ax1.plot(t[50:850],y21[50:850])

ax2 = fig.add_subplot(1,2,2)
ax2.plot(t[50:850],y12[50:850])
ax2.plot(t[50:850],y22[50:850])
