# Figure 7: frequency mismatch for constant g but different A

using OrdinaryDiffEq
using ProgressMeter
using PyPlot
include("my_functions.jl")


###### for changing amplitude A

# parameters
dt = 0.05
omega = .286; 
V_E = -17.63;
A = 0.1;
g = 0.02
M = 500
A0 = range(0,stop=.5,length=M);
g0 = [0.0, 0.02, 0.04];

# initial condition
y0 = [-65.6;0;-60;0.01];

# time
t0 = (0., 2800.);

# results matrix
dphase = zeros(M,3); dfreq = zeros(M,3);

# calculation
p = Progress(M)
@inbounds for (i,A) in enumerate(A0)
    @inbounds for (j,g) in enumerate(g0)
        # solve model

        prob = ODEProblem(ml2!,y0,t0,(A, omega, V_E, g));

        sol = solve(prob,Tsit5(),saveat=dt, dtmax=1.0);

        y1 = copy(sol[1,10001:1:50000]); y2 = copy(sol[3,10001:1:50000]);

        # phase and frequency difference
        dphase[i,j], dfreq[i,j] = phasediff(y1, y2, dt)

    end
    next!(p)
end


PyPlot.clf()
PyPlot.plot(A0,dfreq)
PyPlot.xlabel("A")
PyPlot.legend(["g=0.00","g=0.02","g=0.04"])


